@@ -18,7 +18,7 @@
  *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <Python.h>
+#include "lib/replace/system/python.h"
 #include "includes.h"
 #include "python/py3compat.h"
 
