@@ -19,6 +19,8 @@
  */
 
 #include "includes.h"
+#include "source3/include/client.h"
+#include "source3/libsmb/proto.h"
 #include "ads.h"
 #include "libsmb/namequery.h"
 #include "librpc/gen_ndr/ndr_libnet_join.h"
@@ -35,14 +37,15 @@
 #include "../libds/common/flags.h"
 #include "secrets.h"
 #include "rpc_client/init_lsa.h"
+
 #include "rpc_client/cli_pipe.h"
 #include "../libcli/security/security.h"
 #include "passdb.h"
-#include "libsmb/libsmb.h"
 #include "../libcli/smb/smbXcli_base.h"
 #include "lib/param/loadparm.h"
 #include "libcli/auth/netlogon_creds_cli.h"
 #include "auth/credentials/credentials.h"
+#include "auth/gensec/gensec.h"
 #include "libsmb/dsgetdcname.h"
 #include "rpc_client/util_netlogon.h"
 #include "libnet/libnet_join_offline.h"
@@ -866,7 +869,7 @@ static ADS_STATUS libnet_join_set_etypes(TALLOC_CTX *mem_ctx,
 static bool libnet_join_create_keytab(TALLOC_CTX *mem_ctx,
 				      struct libnet_JoinCtx *r)
 {
-	NTSTATUS ntstatus = sync_pw2keytabs();
+	NTSTATUS ntstatus = sync_pw2keytabs(r->in.dc_name);
 
 	return NT_STATUS_IS_OK(ntstatus);
 }
@@ -900,12 +903,11 @@ static bool libnet_join_derive_salting_principal(TALLOC_CTX *mem_ctx,
 	}
 
 	salt = talloc_strdup(mem_ctx, std_salt);
+	SAFE_FREE(std_salt);
 	if (!salt) {
 		return false;
 	}
 
-	SAFE_FREE(std_salt);
-
 	/* if it's a Windows functional domain, we have to look for the UPN */
 
 	if (domain_func == DS_DOMAIN_FUNCTION_2000) {
@@ -1070,13 +1072,17 @@ static NTSTATUS libnet_join_connect_dc_ipc(TALLOC_CTX *mem_ctx,
 					   struct cli_state **cli)
 {
 	int flags = CLI_FULL_CONNECTION_IPC;
+	struct smb_transports ts =
+		smb_transports_parse("client smb transports",
+				     lp_client_smb_transports());
 	NTSTATUS status;
 
 	status = cli_full_connection_creds(mem_ctx,
 					   cli,
 					   NULL,
 					   dc,
-					   NULL, 0,
+					   NULL,
+					   &ts,
 					   "IPC$", "IPC",
 					   creds,
 					   flags);
@@ -1188,24 +1194,15 @@ static NTSTATUS libnet_join_joindomain_rpc_unsecure(TALLOC_CTX *mem_ctx,
 						    struct cli_state *cli)
 {
 	TALLOC_CTX *frame = talloc_stackframe();
-	struct rpc_pipe_client *authenticate_pipe = NULL;
 	struct rpc_pipe_client *passwordset_pipe = NULL;
 	struct cli_credentials *cli_creds;
 	struct netlogon_creds_cli_context *netlogon_creds = NULL;
-	struct netlogon_creds_CredentialState *creds = NULL;
-	uint32_t netlogon_flags = 0;
+	const struct sockaddr_storage *remote_sockaddr = NULL;
 	size_t len = 0;
 	bool ok;
 	DATA_BLOB new_trust_blob = data_blob_null;
 	NTSTATUS status;
 
-	status = cli_rpc_pipe_open_noauth(cli, &ndr_table_netlogon,
-					  &authenticate_pipe);
-	if (!NT_STATUS_IS_OK(status)) {
-		TALLOC_FREE(frame);
-		return status;
-	}
-
 	if (!r->in.machine_password) {
 		int security = r->in.ads ? SEC_ADS : SEC_DOMAIN;
 
@@ -1237,52 +1234,35 @@ static NTSTATUS libnet_join_joindomain_rpc_unsecure(TALLOC_CTX *mem_ctx,
 				     r->in.passed_machine_password,
 				     CRED_SPECIFIED);
 
-	status = rpccli_create_netlogon_creds_ctx(
-		cli_creds, authenticate_pipe->desthost, r->in.msg_ctx,
-		frame, &netlogon_creds);
+	cli_credentials_add_gensec_features(cli_creds,
+					    GENSEC_FEATURE_NO_DELEGATION,
+					    CRED_SPECIFIED);
+
+	remote_sockaddr = smbXcli_conn_remote_sockaddr(cli->conn);
+
+	status = rpccli_create_netlogon_creds_ctx(cli_creds,
+						  r->in.dc_name,
+						  r->in.msg_ctx,
+						  frame,
+						  &netlogon_creds);
 	if (!NT_STATUS_IS_OK(status)) {
 		TALLOC_FREE(frame);
 		return status;
 	}
 
-	status = rpccli_setup_netlogon_creds(
-		cli, NCACN_NP, netlogon_creds, true /* force_reauth */,
-		cli_creds);
+	status = rpccli_connect_netlogon(cli,
+					 NCACN_NP,
+					 r->in.dc_name,
+					 remote_sockaddr,
+					 netlogon_creds,
+					 true, /* force_reauth */
+					 cli_creds,
+					 &passwordset_pipe);
 	if (!NT_STATUS_IS_OK(status)) {
 		TALLOC_FREE(frame);
 		return status;
 	}
 
-	status = netlogon_creds_cli_get(netlogon_creds, frame, &creds);
-	if (!NT_STATUS_IS_OK(status)) {
-		TALLOC_FREE(frame);
-		return status;
-	}
-
-	netlogon_flags = creds->negotiate_flags;
-	TALLOC_FREE(creds);
-
-	if (netlogon_flags & NETLOGON_NEG_AUTHENTICATED_RPC) {
-		const char *remote_name = smbXcli_conn_remote_name(cli->conn);
-		const struct sockaddr_storage *remote_sockaddr =
-			smbXcli_conn_remote_sockaddr(cli->conn);
-
-		status = cli_rpc_pipe_open_schannel_with_creds(
-				cli,
-				&ndr_table_netlogon,
-				NCACN_NP,
-				netlogon_creds,
-				remote_name,
-				remote_sockaddr,
-				&passwordset_pipe);
-		if (!NT_STATUS_IS_OK(status)) {
-			TALLOC_FREE(frame);
-			return status;
-		}
-	} else {
-		passwordset_pipe = authenticate_pipe;
-	}
-
 	len = strlen(r->in.machine_password);
 	ok = convert_string_talloc(frame, CH_UNIX, CH_UTF16,
 				   r->in.machine_password, len,
@@ -1370,7 +1350,8 @@ static NTSTATUS libnet_join_joindomain_rpc(TALLOC_CTX *mem_ctx,
 
 	b = pipe_hnd->binding_handle;
 
-	status = cli_get_session_key(mem_ctx, pipe_hnd, &session_key);
+	status = dcerpc_binding_handle_transport_session_key(
+				b, mem_ctx, &session_key);
 	if (!NT_STATUS_IS_OK(status)) {
 		DEBUG(0,("Error getting session_key of SAM pipe. Error was %s\n",
 			nt_errstr(status)));
@@ -1669,12 +1650,12 @@ NTSTATUS libnet_join_ok(struct messaging_context *msg_ctx,
 	struct rpc_pipe_client *netlogon_pipe = NULL;
 	struct cli_credentials *cli_creds = NULL;
 	struct netlogon_creds_cli_context *netlogon_creds = NULL;
-	struct netlogon_creds_CredentialState *creds = NULL;
-	uint32_t netlogon_flags = 0;
 	NTSTATUS status;
 	int flags = CLI_FULL_CONNECTION_IPC;
-	const char *remote_name = NULL;
 	const struct sockaddr_storage *remote_sockaddr = NULL;
+	struct smb_transports ts =
+		smb_transports_parse("client smb transports",
+				     lp_client_smb_transports());
 
 	if (!dc_name) {
 		TALLOC_FREE(frame);
@@ -1700,11 +1681,16 @@ NTSTATUS libnet_join_ok(struct messaging_context *msg_ctx,
 					   kerberos_state,
 					   CRED_SPECIFIED);
 
+	cli_credentials_add_gensec_features(cli_creds,
+					    GENSEC_FEATURE_NO_DELEGATION,
+					    CRED_SPECIFIED);
+
 	status = cli_full_connection_creds(frame,
 					   &cli,
 					   NULL,
 					   dc_name,
-					   NULL, 0,
+					   NULL,
+					   &ts,
 					   "IPC$", "IPC",
 					   cli_creds,
 					   flags);
@@ -1722,7 +1708,8 @@ NTSTATUS libnet_join_ok(struct messaging_context *msg_ctx,
 						   &cli,
 						   NULL,
 						   dc_name,
-						   NULL, 0,
+						   NULL,
+						   &ts,
 						   "IPC$", "IPC",
 						   anon_creds,
 						   flags);
@@ -1733,6 +1720,8 @@ NTSTATUS libnet_join_ok(struct messaging_context *msg_ctx,
 		return status;
 	}
 
+	remote_sockaddr = smbXcli_conn_remote_sockaddr(cli->conn);
+
 	status = rpccli_create_netlogon_creds_ctx(cli_creds,
 						  dc_name,
 						  msg_ctx,
@@ -1744,61 +1733,26 @@ NTSTATUS libnet_join_ok(struct messaging_context *msg_ctx,
 		return status;
 	}
 
-	status = rpccli_setup_netlogon_creds(cli, NCACN_NP,
-					     netlogon_creds,
-					     true, /* force_reauth */
-					     cli_creds);
+	status = rpccli_connect_netlogon(cli,
+					 NCACN_NP,
+					 dc_name,
+					 remote_sockaddr,
+					 netlogon_creds,
+					 true, /* force_reauth */
+					 cli_creds,
+					 &netlogon_pipe);
 	if (!NT_STATUS_IS_OK(status)) {
-		DEBUG(0,("connect_to_domain_password_server: "
-			 "unable to open the domain client session to "
-			 "machine %s. Flags[0x%08X] Error was : %s.\n",
-			 dc_name, (unsigned)netlogon_flags,
-			 nt_errstr(status)));
-		cli_shutdown(cli);
-		TALLOC_FREE(frame);
-		return status;
-	}
-
-	status = netlogon_creds_cli_get(netlogon_creds,
-					talloc_tos(),
-					&creds);
-	if (!NT_STATUS_IS_OK(status)) {
-		cli_shutdown(cli);
-		TALLOC_FREE(frame);
-		return status;
-	}
-	netlogon_flags = creds->negotiate_flags;
-	TALLOC_FREE(creds);
-
-	if (!(netlogon_flags & NETLOGON_NEG_AUTHENTICATED_RPC)) {
-		cli_shutdown(cli);
-		TALLOC_FREE(frame);
-		return NT_STATUS_OK;
-	}
-
-	remote_name = smbXcli_conn_remote_name(cli->conn);
-	remote_sockaddr = smbXcli_conn_remote_sockaddr(cli->conn);
-
-	status = cli_rpc_pipe_open_schannel_with_creds(
-		cli, &ndr_table_netlogon, NCACN_NP,
-		netlogon_creds,
-		remote_name,
-		remote_sockaddr,
-		&netlogon_pipe);
-
-	TALLOC_FREE(netlogon_pipe);
-
-	if (!NT_STATUS_IS_OK(status)) {
-		DEBUG(0,("libnet_join_ok: failed to open schannel session "
+		DBG_ERR("failed to open schannel session "
 			"on netlogon pipe to server %s for domain %s. "
 			"Error was %s\n",
-			remote_name,
-			netbios_domain_name, nt_errstr(status)));
+			dc_name, netbios_domain_name, nt_errstr(status));
 		cli_shutdown(cli);
 		TALLOC_FREE(frame);
 		return status;
 	}
 
+	TALLOC_FREE(netlogon_pipe);
+
 	cli_shutdown(cli);
 	TALLOC_FREE(frame);
 	return NT_STATUS_OK;
