@@ -18,7 +18,9 @@
 */
 
 #include "includes.h"
-#include "libsmb/libsmb.h"
+#include "source3/include/client.h"
+#include "source3/libsmb/proto.h"
+#include "source3/libsmb/cli_smb2_fnum.h"
 #include "../lib/util/tevent_ntstatus.h"
 #include "async_smb.h"
 #include "trans2.h"
@@ -53,7 +55,9 @@ static size_t cli_read_max_bufsize(struct cli_state *cli)
 		}
 
 		return useable_space;
-	} else if (smb1cli_conn_capabilities(cli->conn) & CAP_LARGE_READX) {
+	}
+
+	if (smb1cli_conn_capabilities(cli->conn) & CAP_LARGE_READX) {
 		/*
 		 * Note: CAP_LARGE_READX also works with signing
 		 */
@@ -238,7 +242,7 @@ static void cli_read_andx_done(struct tevent_req *subreq)
 
 	state->buf = discard_const_p(uint8_t, smb_base(inbuf)) + SVAL(vwv+6, 0);
 
-	if (trans_oob(smb_len_tcp(inbuf), SVAL(vwv+6, 0), state->received)
+	if (smb_buffer_oob(smb_len_tcp(inbuf), SVAL(vwv+6, 0), state->received)
 	    || ((state->received != 0) && (state->buf < bytes))) {
 		DEBUG(5, ("server returned invalid read&x data offset\n"));
 		tevent_req_nterror(req, NT_STATUS_INVALID_NETWORK_RESPONSE);
@@ -854,74 +858,6 @@ NTSTATUS cli_read(struct cli_state *cli, uint16_t fnum,
 	return NT_STATUS_OK;
 }
 
-/****************************************************************************
-  write to a file using a SMBwrite and not bypassing 0 byte writes
-****************************************************************************/
-
-NTSTATUS cli_smbwrite(struct cli_state *cli, uint16_t fnum, char *buf,
-		      off_t offset, size_t size1, size_t *ptotal)
-{
-	uint8_t *bytes;
-	ssize_t total = 0;
-
-	/*
-	 * 3 bytes prefix
-	 */
-
-	bytes = talloc_array(talloc_tos(), uint8_t, 3);
-	if (bytes == NULL) {
-		return NT_STATUS_NO_MEMORY;
-	}
-	bytes[0] = 1;
-
-	do {
-		uint32_t usable_space = cli_state_available_size(cli, 48);
-		size_t size = MIN(size1, usable_space);
-		struct tevent_req *req;
-		uint16_t vwv[5];
-		uint16_t *ret_vwv;
-		NTSTATUS status;
-
-		SSVAL(vwv+0, 0, fnum);
-		SSVAL(vwv+1, 0, size);
-		SIVAL(vwv+2, 0, offset);
-		SSVAL(vwv+4, 0, 0);
-
-		bytes = talloc_realloc(talloc_tos(), bytes, uint8_t,
-					     size+3);
-		if (bytes == NULL) {
-			return NT_STATUS_NO_MEMORY;
-		}
-		SSVAL(bytes, 1, size);
-		memcpy(bytes + 3, buf + total, size);
-
-		status = cli_smb(talloc_tos(), cli, SMBwrite, 0, 5, vwv,
-				 size+3, bytes, &req, 1, NULL, &ret_vwv,
-				 NULL, NULL);
-		if (!NT_STATUS_IS_OK(status)) {
-			TALLOC_FREE(bytes);
-			return status;
-		}
-
-		size = SVAL(ret_vwv+0, 0);
-		TALLOC_FREE(req);
-		if (size == 0) {
-			break;
-		}
-		size1 -= size;
-		total += size;
-		offset += size;
-
-	} while (size1);
-
-	TALLOC_FREE(bytes);
-
-	if (ptotal != NULL) {
-		*ptotal = total;
-	}
-	return NT_STATUS_OK;
-}
-
 /*
  * Send a write&x request
  */
