@@ -23,7 +23,8 @@
 */
 
 #include "includes.h"
-#include "libsmb/libsmb.h"
+#include "source3/include/client.h"
+#include "source3/libsmb/proto.h"
 #include "libsmbclient.h"
 #include "libsmb_internal.h"
 #include "../libcli/smb/smbXcli_base.h"
@@ -58,22 +59,22 @@ void setup_stat(struct stat *st,
 {
 	st->st_mode = 0;
 
-	if (IS_DOS_DIR(attr)) {
-		st->st_mode = SMBC_DIR_MODE;
+	if (attr & FILE_ATTRIBUTE_DIRECTORY) {
+		st->st_mode = (S_IFDIR | 0555);
 	} else {
-		st->st_mode = SMBC_FILE_MODE;
+		st->st_mode = (S_IFREG | 0444);
 	}
 
-	if (IS_DOS_ARCHIVE(attr)) {
+	if (attr & FILE_ATTRIBUTE_ARCHIVE) {
 		st->st_mode |= S_IXUSR;
 	}
-	if (IS_DOS_SYSTEM(attr)) {
+	if (attr & FILE_ATTRIBUTE_SYSTEM) {
 		st->st_mode |= S_IXGRP;
 	}
-	if (IS_DOS_HIDDEN(attr)) {
+	if (attr & FILE_ATTRIBUTE_HIDDEN) {
 		st->st_mode |= S_IXOTH;
 	}
-	if (!IS_DOS_READONLY(attr)) {
+	if (!(attr & FILE_ATTRIBUTE_READONLY)) {
 		st->st_mode |= S_IWUSR;
 	}
 
@@ -90,7 +91,7 @@ void setup_stat(struct stat *st,
 	st->st_uid = getuid();
 	st->st_gid = getgid();
 
-	if (IS_DOS_DIR(attr)) {
+	if (attr & FILE_ATTRIBUTE_DIRECTORY) {
 		st->st_nlink = 2;
 	} else {
 		st->st_nlink = 1;
@@ -114,48 +115,6 @@ void setup_stat(struct stat *st,
 	set_mtimensec(st, write_time_ts.tv_nsec);
 }
 
-void setup_stat_from_stat_ex(const struct stat_ex *stex,
-			     const char *fname,
-			     struct stat *st)
-{
-	st->st_atime = stex->st_ex_atime.tv_sec;
-	set_atimensec(st, stex->st_ex_atime.tv_nsec);
-
-	st->st_ctime = stex->st_ex_ctime.tv_sec;
-	set_ctimensec(st, stex->st_ex_ctime.tv_nsec);
-
-	st->st_mtime = stex->st_ex_mtime.tv_sec;
-	set_mtimensec(st, stex->st_ex_mtime.tv_nsec);
-
-	st->st_mode = stex->st_ex_mode;
-	st->st_size = stex->st_ex_size;
-#ifdef HAVE_STAT_ST_BLKSIZE
-	st->st_blksize = 512;
-#endif
-#ifdef HAVE_STAT_ST_BLOCKS
-	st->st_blocks = (st->st_size + 511) / 512;
-#endif
-#ifdef HAVE_STRUCT_STAT_ST_RDEV
-	st->st_rdev = 0;
-#endif
-	st->st_uid = stex->st_ex_uid;
-	st->st_gid = stex->st_ex_gid;
-
-	st->st_nlink = stex->st_ex_nlink;
-
-	if (stex->st_ex_ino == 0) {
-		st->st_ino = 0;
-		if (fname != NULL) {
-			st->st_ino = generate_inode(fname);
-		}
-	} else {
-		st->st_ino = stex->st_ex_ino;
-	}
-
-	st->st_dev = stex->st_ex_dev;
-
-}
-
 /*
  * Routine to stat a file given a name
  */
@@ -173,17 +132,18 @@ SMBC_stat_ctx(SMBCCTX *context,
 	char *workgroup = NULL;
 	char *path = NULL;
 	uint16_t port = 0;
+	NTSTATUS status;
 	TALLOC_CTX *frame = talloc_stackframe();
 
 	if (!context || !context->internal->initialized) {
-		errno = EINVAL;  /* Best I can think of ... */
 		TALLOC_FREE(frame);
+		errno = EINVAL;  /* Best I can think of ... */
 		return -1;
 	}
 
 	if (!fname) {
-		errno = EINVAL;
 		TALLOC_FREE(frame);
+		errno = EINVAL;
 		return -1;
 	}
 
@@ -200,16 +160,16 @@ SMBC_stat_ctx(SMBCCTX *context,
                             &user,
                             &password,
                             NULL)) {
-		errno = EINVAL;
 		TALLOC_FREE(frame);
+		errno = EINVAL;
                 return -1;
         }
 
 	if (!user || user[0] == (char)0) {
 		user = talloc_strdup(frame, smbc_getUser(context));
 		if (!user) {
-			errno = ENOMEM;
 			TALLOC_FREE(frame);
+			errno = ENOMEM;
 			return -1;
 		}
 	}
@@ -217,13 +177,16 @@ SMBC_stat_ctx(SMBCCTX *context,
 	srv = SMBC_server(frame, context, True,
                           server, port, share, &workgroup, &user, &password);
 	if (!srv) {
+		int err = errno;
 		TALLOC_FREE(frame);
+		errno = err;
 		return -1;  /* errno set by SMBC_server */
 	}
 
-	if (!SMBC_getatr(context, srv, path, st)) {
-		errno = SMBC_errno(context, srv->cli);
+	status = SMBC_getatr(context, srv, path, st);
+	if (!NT_STATUS_IS_OK(status)) {
 		TALLOC_FREE(frame);
+		errno = cli_status_to_errno(status);
 		return -1;
 	}
 
@@ -259,14 +222,14 @@ SMBC_fstat_ctx(SMBCCTX *context,
 	NTSTATUS status;
 
 	if (!context || !context->internal->initialized) {
-		errno = EINVAL;
 		TALLOC_FREE(frame);
+		errno = EINVAL;
 		return -1;
 	}
 
 	if (!SMBC_dlist_contains(context->internal->files, file)) {
-		errno = EBADF;
 		TALLOC_FREE(frame);
+		errno = EBADF;
 		return -1;
 	}
 
@@ -287,8 +250,8 @@ SMBC_fstat_ctx(SMBCCTX *context,
                             &user,
                             &password,
                             NULL)) {
-                errno = EINVAL;
 		TALLOC_FREE(frame);
+                errno = EINVAL;
                 return -1;
         }
 
@@ -301,8 +264,8 @@ SMBC_fstat_ctx(SMBCCTX *context,
 				  &targetcli, &targetpath);
 	if (!NT_STATUS_IS_OK(status)) {
 		d_printf("Could not resolve %s\n", path);
-                errno = ENOENT;
 		TALLOC_FREE(frame);
+                errno = ENOENT;
 		return -1;
 	}
 	/*d_printf(">>>fstat: resolved path as %s\n", targetpath);*/
@@ -314,8 +277,8 @@ SMBC_fstat_ctx(SMBCCTX *context,
 				     &write_time_ts,
 				     &change_time_ts,
 				     &ino))) {
-		errno = EINVAL;
 		TALLOC_FREE(frame);
+		errno = EINVAL;
 		return -1;
 	}
 
@@ -350,7 +313,9 @@ SMBC_statvfs_ctx(SMBCCTX *context,
 
         /* Determine if the provided path is a file or a folder */
         if (SMBC_stat_ctx(context, path, &statbuf) < 0) {
+		int err = errno;
 		TALLOC_FREE(frame);
+		errno = err;
                 return -1;
         }
 
@@ -358,7 +323,9 @@ SMBC_statvfs_ctx(SMBCCTX *context,
         if (S_ISDIR(statbuf.st_mode)) {
                 /* It's a directory. */
                 if ((pFile = SMBC_opendir_ctx(context, path)) == NULL) {
+			int err = errno;
 			TALLOC_FREE(frame);
+			errno = err;
                         return -1;
                 }
                 bIsDir = true;
@@ -366,7 +333,9 @@ SMBC_statvfs_ctx(SMBCCTX *context,
                 /* It's a file. */
                 if ((pFile = SMBC_open_ctx(context, path,
                                            O_RDONLY, 0)) == NULL) {
+			int err = errno;
 			TALLOC_FREE(frame);
+			errno = err;
                         return -1;
                 }
                 bIsDir = false;
