@@ -22,7 +22,6 @@
 
 struct iovec;
 
-#include "lib/util/iov_buf.h"
 #include <tevent.h>
 #include "lib/tsocket/tsocket.h"
 #include "source3/lib/substitute.h"
@@ -55,12 +54,14 @@ int virusfilter_vfs_next_move(
 	const struct smb_filename *smb_fname_dst)
 {
 	int result;
+	struct vfs_rename_how rhow = { .flags = 0, };
 
 	result = SMB_VFS_NEXT_RENAMEAT(vfs_h,
 			vfs_h->conn->cwd_fsp,
 			smb_fname_src,
 			vfs_h->conn->cwd_fsp,
-			smb_fname_dst);
+			smb_fname_dst,
+			&rhow);
 	if (result == 0 || errno != EXDEV) {
 		return result;
 	}
