@@ -27,6 +27,7 @@
 #include "dbwrap/dbwrap.h"
 #include "dbwrap/dbwrap_rbt.h"
 #include "../libcli/registry/util_reg.h"
+#include "lib/util/string_wrappers.h"
 
 #undef DBGC_CLASS
 #define DBGC_CLASS DBGC_REGISTRY
@@ -62,7 +63,7 @@ struct regsubkey_ctr {
  talloc()'d since the methods use the object pointer as the talloc
  context for internal private data.
 
- There is no longer a regval_ctr_intit() and regval_ctr_destroy()
+ There is no longer a regval_ctr_init() and regval_ctr_destroy()
  pair of functions.  Simply talloc_zero() and TALLOC_FREE() the
  object.
 
@@ -298,7 +299,7 @@ bool regsubkey_ctr_key_exists( struct regsubkey_ctr *ctr, const char *keyname )
  How many keys does the container hold ?
  **********************************************************************/
 
-int regsubkey_ctr_numkeys( struct regsubkey_ctr *ctr )
+uint32_t regsubkey_ctr_numkeys( struct regsubkey_ctr *ctr )
 {
 	return ctr->num_subkeys;
 }
@@ -340,7 +341,7 @@ WERROR regval_ctr_init(TALLOC_CTX *mem_ctx, struct regval_ctr **ctr)
  How many keys does the container hold ?
  **********************************************************************/
 
-int regval_ctr_numvals(struct regval_ctr *ctr)
+uint32_t regval_ctr_numvals(struct regval_ctr *ctr)
 {
 	return ctr->num_values;
 }
