@@ -5,7 +5,7 @@
 # Copyright (C) 2011 Björn Baumbach <bb@sernet.de>
 
 if [ $# -lt 5 ]; then
-	echo "Usage: test_net_registry.sh SCRIPTDIR SERVERCONFFILE NET CONFIGURATION DBWRAP_TOOL"
+	echo "Usage: test_net_registry_check.sh SCRIPTDIR SERVERCONFFILE NET CONFIGURATION DBWRAP_TOOL"
 	exit 1
 fi
 
@@ -21,7 +21,7 @@ NETREG="${NET} registry"
 REGORIG="$(grep 'state directory = ' $SERVERCONFFILE | sed 's/[^=]*=//')/registry.tdb"
 REG=$REGORIG.wip
 
-incdir=`dirname $0`/../../../testprogs/blackbox
+incdir=$(dirname $0)/../../../testprogs/blackbox
 . $incdir/subunit.sh
 
 failed=0
@@ -30,7 +30,7 @@ failed=0
 regcheck()
 {
 	ALLOWEDERR="Check database:|INFO: version ="
-	ERRSTR=$(${NETREG} check $REG $@ 2>&1 | egrep -v "$ALLOWEDERR")
+	ERRSTR=$(${NETREG} check $REG "$@" 2>&1 | egrep -v "$ALLOWEDERR")
 }
 
 # try to repair registry
@@ -118,24 +118,24 @@ test_strangeletters()
 )
 
 testit "simple" \
-	test_simple || \
-	failed=`expr $failed + 1`
+	test_simple ||
+	failed=$(expr $failed + 1)
 
 testit "damages_registry" \
-	test_damage || \
-	failed=`expr $failed + 1`
+	test_damage ||
+	failed=$(expr $failed + 1)
 
 testit "duplicate" \
-	test_duplicate || \
-	failed=`expr $failed + 1`
+	test_duplicate ||
+	failed=$(expr $failed + 1)
 
 testit "slashes" \
-	test_slashes || \
-	failed=`expr $failed + 1`
+	test_slashes ||
+	failed=$(expr $failed + 1)
 
 testit "uppercase" \
-	test_uppercase || \
-	failed=`expr $failed + 1`
+	test_uppercase ||
+	failed=$(expr $failed + 1)
 
 #Can't repair this atm
 #testit "strangeletters" \
@@ -143,4 +143,3 @@ testit "uppercase" \
 #	failed=`expr $failed + 1`
 
 testok $0 $failed
-
