@@ -26,7 +26,8 @@
 #include "../librpc/gen_ndr/rap.h"
 #include "../librpc/gen_ndr/svcctl.h"
 #include "utils/net.h"
-#include "libsmb/libsmb.h"
+#include "source3/include/client.h"
+#include "source3/libsmb/proto.h"
 #include "clirap2.h"
 #include "../libcli/smb/smbXcli_base.h"
 
@@ -301,7 +302,7 @@ int net_rap_share(struct net_context *c, int argc, const char **argv)
 
 	if (argc == 0) {
 		struct cli_state *cli;
-		int ret;
+		NTSTATUS status;
 
 		if (c->display_usage) {
 			d_printf(_("Usage:\n"));
@@ -319,12 +320,12 @@ int net_rap_share(struct net_context *c, int argc, const char **argv)
 	"\nEnumerating shared resources (exports) on remote server:\n\n"
 	"\nShare name   Type     Description\n"
 	"----------   ----     -----------\n"));
-			ret = cli_RNetShareEnum(cli, long_share_fn, NULL);
+			status = cli_RNetShareEnum(cli, long_share_fn, NULL);
 		} else {
-			ret = cli_RNetShareEnum(cli, share_fn, NULL);
+			status = cli_RNetShareEnum(cli, share_fn, NULL);
 		}
 		cli_shutdown(cli);
-		return ret;
+		return NT_STATUS_IS_OK(status) ? 0 : -1;
 	}
 
 	return net_run_function(c, argc, argv, "net rap share", func);
@@ -535,7 +536,7 @@ static int net_rap_server_domain(struct net_context *c, int argc,
 				 const char **argv)
 {
 	struct cli_state *cli;
-	int ret;
+	NTSTATUS status;
 
 	if (c->display_usage) {
 		d_printf("%s\n%s",
@@ -552,10 +553,13 @@ static int net_rap_server_domain(struct net_context *c, int argc,
 		   "\tServer name          Server description\n"
 		   "\t-------------        ----------------------------\n"));
 
-	ret = cli_NetServerEnum(cli, cli->server_domain, SV_TYPE_ALL,
-				display_server_func,NULL);
+	status = cli_NetServerEnum(cli,
+				   cli->server_domain,
+				   SV_TYPE_ALL,
+				   display_server_func,
+				   NULL);
 	cli_shutdown(cli);
-	return ret;
+	return NT_STATUS_IS_OK(status) ? 0 : -1;
 }
 
 int net_rap_server(struct net_context *c, int argc, const char **argv)
@@ -598,7 +602,7 @@ int net_rap_domain_usage(struct net_context *c, int argc, const char **argv)
 int net_rap_domain(struct net_context *c, int argc, const char **argv)
 {
 	struct cli_state *cli;
-	int ret;
+	NTSTATUS status;
 
 	if (c->display_usage)
 		return net_rap_domain_usage(c, argc, argv);
@@ -610,10 +614,13 @@ int net_rap_domain(struct net_context *c, int argc, const char **argv)
 		   "\tDomain name          Server name of Browse Master\n"
 		   "\t-------------        ----------------------------\n"));
 
-	ret = cli_NetServerEnum(cli, cli->server_domain, SV_TYPE_DOMAIN_ENUM,
-				display_server_func,NULL);
+	status = cli_NetServerEnum(cli,
+				   cli->server_domain,
+				   SV_TYPE_DOMAIN_ENUM,
+				   display_server_func,
+				   NULL);
 	cli_shutdown(cli);
-	return ret;
+	return NT_STATUS_IS_OK(status) ? 0 : -1;
 }
 
 int net_rap_printq_usage(struct net_context *c, int argc, const char **argv)
@@ -712,7 +719,7 @@ static int rap_printq_info(struct net_context *c, int argc, const char **argv)
 static int rap_printq_delete(struct net_context *c, int argc, const char **argv)
 {
 	struct cli_state *cli;
-	int ret;
+	NTSTATUS status;
 
 	if (argc == 0 || c->display_usage)
                 return net_rap_printq_usage(c, argc, argv);
@@ -720,9 +727,12 @@ static int rap_printq_delete(struct net_context *c, int argc, const char **argv)
 	if (!NT_STATUS_IS_OK(net_make_ipc_connection(c, 0, &cli)))
                 return -1;
 
-	ret = cli_printjob_del(cli, atoi(argv[0]));
+	status = cli_printjob_del(cli, atoi(argv[0]));
 	cli_shutdown(cli);
-	return ret;
+	if (!NT_STATUS_IS_OK(status)) {
+		return -1;
+	}
+	return 0;
 }
 
 int net_rap_printq(struct net_context *c, int argc, const char **argv)
@@ -1211,6 +1221,10 @@ int net_rap_service(struct net_context *c, int argc, const char **argv)
 			d_printf(_("Service name          Comment\n"
 		                   "-----------------------------\n"));
 			ret = cli_RNetServiceEnum(cli, long_group_fn, NULL);
+			if (ret) {
+				cli_shutdown(cli);
+				return ret;
+			}
 		}
 		ret = cli_RNetServiceEnum(cli, service_fn, NULL);
 		cli_shutdown(cli);
@@ -1233,7 +1247,7 @@ int net_rap_password_usage(struct net_context *c, int argc, const char **argv)
 int net_rap_password(struct net_context *c, int argc, const char **argv)
 {
 	struct cli_state *cli;
-	int ret;
+	NTSTATUS status;
 
 	if (argc < 3 || c->display_usage)
                 return net_rap_password_usage(c, argc, argv);
@@ -1242,9 +1256,9 @@ int net_rap_password(struct net_context *c, int argc, const char **argv)
                 return -1;
 
 	/* BB Add check for password lengths? */
-	ret = cli_oem_change_password(cli, argv[0], argv[2], argv[1]);
+	status = cli_oem_change_password(cli, argv[0], argv[2], argv[1]);
 	cli_shutdown(cli);
-	return ret;
+	return NT_STATUS_IS_OK(status) ? 0 : -1;
 }
 
 int net_rap_admin_usage(struct net_context *c, int argc, const char **argv)
