@@ -25,6 +25,7 @@
 
 #include "idmap_autorid_tdb.h"
 #include "../libcli/security/dom_sid.h"
+#include "lib/util/string_wrappers.h"
 
 /**
  * Build the database keystring for getting a range
@@ -88,7 +89,7 @@ static NTSTATUS idmap_autorid_addrange_action(struct db_context *db,
 	NTSTATUS ret;
 	uint32_t hwm;
 	char *numstr;
-	struct autorid_global_config *globalcfg;
+	struct autorid_global_config globalcfg = {0};
 	fstring keystr;
 	uint32_t increment;
 	TALLOC_CTX *mem_ctx = NULL;
@@ -96,18 +97,19 @@ static NTSTATUS idmap_autorid_addrange_action(struct db_context *db,
 	ctx = (struct idmap_autorid_addrange_ctx *)private_data;
 	range = ctx->range;
 	acquire = ctx->acquire;
-	requested_rangenum = range->rangenum;
 
 	if (db == NULL) {
-		DEBUG(3, ("Invalid database argument: NULL"));
+		DEBUG(3, ("Invalid database argument: NULL\n"));
 		return NT_STATUS_INVALID_PARAMETER;
 	}
 
 	if (range == NULL) {
-		DEBUG(3, ("Invalid range argument: NULL"));
+		DEBUG(3, ("Invalid range argument: NULL\n"));
 		return NT_STATUS_INVALID_PARAMETER;
 	}
 
+	requested_rangenum = range->rangenum;
+
 	DEBUG(10, ("Adding new range for domain %s "
 		   "(domain_range_index=%"PRIu32")\n",
 		   range->domsid, range->domain_range_index));
@@ -127,6 +129,21 @@ static NTSTATUS idmap_autorid_addrange_action(struct db_context *db,
 		if (acquire) {
 			DEBUG(10, ("domain range already allocated - "
 				   "Not adding!\n"));
+
+			ret = idmap_autorid_loadconfig(db, &globalcfg);
+			if (!NT_STATUS_IS_OK(ret)) {
+				DEBUG(1, ("Fatal error while fetching "
+					  "configuration: %s\n",
+					  nt_errstr(ret)));
+				goto error;
+			}
+
+			range->rangenum = stored_rangenum;
+			range->low_id = globalcfg.minvalue
+				+ range->rangenum * globalcfg.rangesize;
+			range->high_id =
+				range->low_id  + globalcfg.rangesize - 1;
+
 			return NT_STATUS_OK;
 		}
 
@@ -152,7 +169,7 @@ static NTSTATUS idmap_autorid_addrange_action(struct db_context *db,
 
 	mem_ctx = talloc_stackframe();
 
-	ret = idmap_autorid_loadconfig(db, mem_ctx, &globalcfg);
+	ret = idmap_autorid_loadconfig(db, &globalcfg);
 	if (!NT_STATUS_IS_OK(ret)) {
 		DEBUG(1, ("Fatal error while fetching configuration: %s\n",
 			  nt_errstr(ret)));
@@ -166,11 +183,15 @@ static NTSTATUS idmap_autorid_addrange_action(struct db_context *db,
 		requested_rangenum = hwm;
 	}
 
-	if (requested_rangenum >= globalcfg->maxranges) {
-		DEBUG(1, ("Not enough ranges available: New range %u must be "
-			  "smaller than configured maximum number of ranges "
-			  "(%u).\n",
-			  requested_rangenum, globalcfg->maxranges));
+	if (requested_rangenum >= globalcfg.maxranges) {
+		DBG_WARNING("Not enough ranges available: New range %u can't "
+			    "be allocated. Consider increasing the range "
+			    "[%u-%u] by %u.\n",
+			   requested_rangenum,
+			   globalcfg.minvalue,
+			   globalcfg.minvalue +
+				(globalcfg.maxranges * globalcfg.rangesize),
+			   globalcfg.rangesize);
 		ret = NT_STATUS_NO_MEMORY;
 		goto error;
 	}
@@ -256,9 +277,9 @@ static NTSTATUS idmap_autorid_addrange_action(struct db_context *db,
 
 	range->rangenum = requested_rangenum;
 
-	range->low_id = globalcfg->minvalue
-		      + range->rangenum * globalcfg->rangesize;
-	range->high_id = range->low_id  + globalcfg->rangesize - 1;
+	range->low_id = globalcfg.minvalue
+		      + range->rangenum * globalcfg.rangesize;
+	range->high_id = range->low_id  + globalcfg.rangesize - 1;
 
 	ret = NT_STATUS_OK;
 
@@ -298,8 +319,8 @@ NTSTATUS idmap_autorid_setrange(struct db_context *db,
 	return status;
 }
 
-static NTSTATUS idmap_autorid_acquire_range(struct db_context *db,
-					    struct autorid_range_config *range)
+NTSTATUS idmap_autorid_acquire_range(struct db_context *db,
+				     struct autorid_range_config *range)
 {
 	return idmap_autorid_addrange(db, range, true);
 }
@@ -308,7 +329,7 @@ static NTSTATUS idmap_autorid_getrange_int(struct db_context *db,
 					   struct autorid_range_config *range)
 {
 	NTSTATUS status = NT_STATUS_INVALID_PARAMETER;
-	struct autorid_global_config *globalcfg = NULL;
+	struct autorid_global_config globalcfg = {0};
 	fstring keystr;
 
 	if (db == NULL || range == NULL) {
@@ -333,16 +354,14 @@ static NTSTATUS idmap_autorid_getrange_int(struct db_context *db,
 		goto done;
 	}
 
-	status = idmap_autorid_loadconfig(db, talloc_tos(), &globalcfg);
+	status = idmap_autorid_loadconfig(db, &globalcfg);
 	if (!NT_STATUS_IS_OK(status)) {
-		DEBUG(1, ("Failed to read global configuration"));
+		DEBUG(1, ("Failed to read global configuration\n"));
 		goto done;
 	}
-	range->low_id = globalcfg->minvalue
-		      + range->rangenum * globalcfg->rangesize;
-	range->high_id = range->low_id  + globalcfg->rangesize - 1;
-
-	TALLOC_FREE(globalcfg);
+	range->low_id = globalcfg.minvalue
+		      + range->rangenum * globalcfg.rangesize;
+	range->high_id = range->low_id  + globalcfg.rangesize - 1;
 done:
 	return status;
 }
@@ -602,7 +621,7 @@ static NTSTATUS idmap_autorid_delete_range_by_num_action(struct db_context *db,
 	struct idmap_autorid_delete_range_by_num_ctx *ctx =
 		(struct idmap_autorid_delete_range_by_num_ctx *)private_data;
 	uint32_t rangenum;
-	char *keystr;
+	char *keystr = NULL;
 	char *range_keystr;
 	TDB_DATA val;
 	NTSTATUS status;
@@ -844,10 +863,9 @@ bool idmap_autorid_parse_configstr(const char *configstr,
 }
 
 NTSTATUS idmap_autorid_loadconfig(struct db_context *db,
-				  TALLOC_CTX *mem_ctx,
-				  struct autorid_global_config **result)
+				  struct autorid_global_config *result)
 {
-	struct autorid_global_config *cfg;
+	struct autorid_global_config cfg = {0};
 	NTSTATUS status;
 	bool ok;
 	char *configstr = NULL;
@@ -856,25 +874,20 @@ NTSTATUS idmap_autorid_loadconfig(struct db_context *db,
 		return NT_STATUS_INVALID_PARAMETER;
 	}
 
-	status = idmap_autorid_getconfigstr(db, mem_ctx, &configstr);
+	status = idmap_autorid_getconfigstr(db, db, &configstr);
 	if (!NT_STATUS_IS_OK(status)) {
 		return status;
 	}
 
-	cfg = talloc_zero(mem_ctx, struct autorid_global_config);
-	if (cfg == NULL) {
-		return NT_STATUS_NO_MEMORY;
-	}
-
-	ok = idmap_autorid_parse_configstr(configstr, cfg);
+	ok = idmap_autorid_parse_configstr(configstr, &cfg);
+	TALLOC_FREE(configstr);
 	if (!ok) {
-		talloc_free(cfg);
 		return NT_STATUS_INVALID_PARAMETER;
 	}
 
 	DEBUG(10, ("Loaded previously stored configuration "
 		   "minvalue:%d rangesize:%d\n",
-		   cfg->minvalue, cfg->rangesize));
+		   cfg.minvalue, cfg.rangesize));
 
 	*result = cfg;
 
@@ -885,7 +898,7 @@ NTSTATUS idmap_autorid_saveconfig(struct db_context *db,
 				  struct autorid_global_config *cfg)
 {
 
-	struct autorid_global_config *storedconfig = NULL;
+	struct autorid_global_config storedconfig = {0};
 	NTSTATUS status = NT_STATUS_INVALID_PARAMETER;
 	TDB_DATA data;
 	char *cfgstr;
@@ -907,10 +920,11 @@ NTSTATUS idmap_autorid_saveconfig(struct db_context *db,
 		goto done;
 	}
 
-	status = idmap_autorid_loadconfig(db, frame, &storedconfig);
+	status = idmap_autorid_loadconfig(db, &storedconfig);
 	if (NT_STATUS_EQUAL(status, NT_STATUS_NOT_FOUND)) {
 		DEBUG(5, ("No configuration found. Storing initial "
 			  "configuration.\n"));
+		storedconfig = *cfg;
 	} else if (!NT_STATUS_IS_OK(status)) {
 		DEBUG(1, ("Error loading configuration: %s\n",
 			  nt_errstr(status)));
@@ -918,9 +932,8 @@ NTSTATUS idmap_autorid_saveconfig(struct db_context *db,
 	}
 
 	/* did the minimum value or rangesize change? */
-	if (storedconfig &&
-	    ((storedconfig->minvalue != cfg->minvalue) ||
-	     (storedconfig->rangesize != cfg->rangesize)))
+	if ((storedconfig.minvalue != cfg->minvalue) ||
+	    (storedconfig.rangesize != cfg->rangesize))
 	{
 		DEBUG(1, ("New configuration values for rangesize or "
 			  "minimum uid value conflict with previously "
