@@ -27,6 +27,9 @@
 #include "auth/auth.h"
 #include "kdc/kpasswd-helper.h"
 
+#undef DBGC_CLASS
+#define DBGC_CLASS DBGC_KERBEROS
+
 bool kpasswd_make_error_reply(TALLOC_CTX *mem_ctx,
 			      krb5_error_code error_code,
 			      const char *error_string,
@@ -218,7 +221,6 @@ NTSTATUS kpasswd_samdb_set_password(TALLOC_CTX *mem_ctx,
 	status = samdb_set_password(samdb,
 				    mem_ctx,
 				    target_dn,
-				    NULL, /* domain_dn */
 				    password,
 				    NULL, /* ntNewHash */
 				    DSDB_PASSWORD_RESET,
