@@ -22,6 +22,8 @@
 #include <netapi.h>
 #include "torture/libnetapi/proto.h"
 
+#undef strcasecmp
+
 #define TORTURE_TEST_USER "testuser"
 
 #define NETAPI_STATUS(tctx, x,y,fn) \
@@ -447,7 +449,7 @@ bool torture_libnetapi_group(struct torture_context *tctx)
 		goto out;
 	}
 
-	/* set it again via exlicit member set */
+	/* set it again via explicit member set */
 
 	status = test_netgroupsetusers(tctx, hostname, groupname2, 0, 1, &username);
 	if (status) {
