@@ -18,7 +18,8 @@
 */
 
 #include "includes.h"
-#include "lib/cmdline/popt_common.h"
+#include "lib/util/util_file.h"
+#include "lib/cmdline/cmdline.h"
 #include "lib/events/events.h"
 #include "system/filesys.h"
 #include "system/time.h"
@@ -161,10 +162,10 @@ static struct smbcli_state *connect_one(struct tevent_context *ev,
 		printf("\\\\%s\\%s\n", server, share);
 		status = smbcli_full_connection(NULL, &c, 
 						server, 
-						lpcfg_smb_ports(lp_ctx),
 						share, NULL,
 						lpcfg_socket_options(lp_ctx),
-						servers[snum], 
+						servers[snum],
+						lp_ctx,
 						lpcfg_resolve_context(lp_ctx),
 						ev, &options, &session_options,
 						lpcfg_gensec_settings(mem_ctx, lp_ctx));
@@ -558,7 +559,11 @@ int main(int argc, const char *argv[])
 	poptContext pc;
 	int argc_new, i;
 	char **argv_new;
-	enum {OPT_UNCLIST=1000};
+	enum {
+		OPT_UNCLIST=1000,
+		OPT_USER1,
+		OPT_USER2,
+	};
 	struct poptOption long_options[] = {
 		POPT_AUTOHELP
 		{"seed",	  0, POPT_ARG_INT,  &seed, 	0,	"Seed to use for randomizer", 	NULL},
@@ -573,15 +578,18 @@ int main(int argc, const char *argv[])
 		{"zerozero",      0, POPT_ARG_NONE, &zero_zero,    0,      "do zero/zero lock", NULL},
 		{"exacterrors",   0, POPT_ARG_NONE, &exact_error_codes,0,"use exact error codes", NULL},
 		{"unclist",	  0, POPT_ARG_STRING,	NULL, 	OPT_UNCLIST,	"unclist", 	NULL},
-		{ "user", 'U',       POPT_ARG_STRING, NULL, 'U', "Set the network username", "[DOMAIN/]USERNAME[%PASSWORD]" },
+		{"user1",         0, POPT_ARG_STRING, NULL, OPT_USER1, "Set first network username", "[DOMAIN/]USERNAME[%PASSWORD]" },
+		{"user2",         0, POPT_ARG_STRING, NULL, OPT_USER2, "Set second network username", "[DOMAIN/]USERNAME[%PASSWORD]" },
 		POPT_COMMON_SAMBA
 		POPT_COMMON_CONNECTION
 		POPT_COMMON_CREDENTIALS
 		POPT_COMMON_VERSION
-		{ NULL }
+		POPT_LEGACY_S4
+		POPT_TABLEEND
 	};
 	TALLOC_CTX *mem_ctx = NULL;
 	int ret = -1;
+	bool ok;
 
 	setlinebuf(stdout);
 	seed = time(NULL);
@@ -592,12 +600,31 @@ int main(int argc, const char *argv[])
 		exit(1);
 	}
 
-	pc = poptGetContext("locktest", argc, argv, long_options,
-			    POPT_CONTEXT_KEEP_FIRST);
+	ok = samba_cmdline_init(mem_ctx,
+				SAMBA_CMDLINE_CONFIG_CLIENT,
+				false /* require_smbconf */);
+	if (!ok) {
+		DBG_ERR("Failed to init cmdline parser!\n");
+		TALLOC_FREE(mem_ctx);
+		exit(1);
+	}
+
+
+	pc = samba_popt_get_context("locktest",
+				    argc,
+				    argv,
+				    long_options,
+				    POPT_CONTEXT_KEEP_FIRST);
+	if (pc == NULL) {
+		DBG_ERR("Failed to setup popt context!\n");
+		TALLOC_FREE(mem_ctx);
+		exit(1);
+	}
 
 	poptSetOtherOptionHelp(pc, "<unc1> <unc2>");
 
-	lp_ctx = cmdline_lp_ctx;
+	lp_ctx = samba_cmdline_get_lp_ctx();
+
 	servers[0] = cli_credentials_init(mem_ctx);
 	servers[1] = cli_credentials_init(mem_ctx);
 	cli_credentials_guess(servers[0], lp_ctx);
@@ -606,17 +633,25 @@ int main(int argc, const char *argv[])
 	while((opt = poptGetNextOpt(pc)) != -1) {
 		switch (opt) {
 		case OPT_UNCLIST:
-			lpcfg_set_cmdline(cmdline_lp_ctx, "torture:unclist", poptGetOptArg(pc));
+			lpcfg_set_cmdline(lp_ctx, "torture:unclist", poptGetOptArg(pc));
 			break;
-		case 'U':
-			if (username_count == 2) {
-				usage(pc);
-				talloc_free(mem_ctx);
-				exit(1);
-			}
-			cli_credentials_parse_string(servers[username_count], poptGetOptArg(pc), CRED_SPECIFIED);
+		case OPT_USER1:
+			cli_credentials_parse_string(servers[0],
+						     poptGetOptArg(pc),
+						     CRED_SPECIFIED);
 			username_count++;
 			break;
+		case OPT_USER2:
+			cli_credentials_parse_string(servers[1],
+						     poptGetOptArg(pc),
+						     CRED_SPECIFIED);
+			username_count++;
+			break;
+		case POPT_ERROR_BADOPT:
+			fprintf(stderr, "\nInvalid option %s: %s\n\n",
+				poptBadOption(pc, 0), poptStrerror(opt));
+			poptPrintUsage(pc, stderr, 0);
+			exit(1);
 		}
 	}
 
@@ -641,8 +676,6 @@ int main(int argc, const char *argv[])
 		all_string_sub(share[server],"/","\\",0);
 	}
 
-	lp_ctx = cmdline_lp_ctx;
-
 	if (username_count == 0) {
 		usage(pc);
 		poptFreeContext(pc);
